skhubness.neighbors.LSH
=======================

.. currentmodule:: skhubness.neighbors

.. autoclass:: LSH

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LSH.__init__
      ~LSH.fit
      ~LSH.kneighbors
      ~LSH.radius_neighbors
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~LSH.valid_metrics
   
   